@@ -56,6 +56,16 @@ class Delegate(Module):
                                                          amount,
                                                          )
 
+    @contract_transaction
+    def redeem_delegate(self,
+                        txn=None,
+                        private_key=None,
+                        ):
+        """
+        领取已经解锁的委托金
+        """
+        return self.web3.ppos.delegate.redeem_delegate()
+
     def get_delegate_info(self,
                           address=None,
                           node_id=None,
@@ -75,6 +85,20 @@ class Delegate(Module):
         else:
             return DelegateInfo(delegate_info)
 
+    def get_delegate_lock_info(self,
+                               address=None,
+                               ):
+        """ 获取地址处于锁定期的委托信息
+        """
+        address = address or self.default_account.address
+
+        delegate_lock_info = self.web3.ppos.delegate.get_delegate_lock_info(address)
+        # todo: 根据实际情况补全
+        if delegate_lock_info == 'Query delegate info failed:Delegate info is not found':
+            return None
+        else:
+            return DelegateInfo(delegate_lock_info)
+
     def get_delegate_list(self, address=None):
         """ 获取地址的全部委托信息
         """
@@ -83,7 +107,7 @@ class Delegate(Module):
         # return self.web3.ppos.delegate.get_delegate_list(address)
         delegate_list = self.web3.ppos.delegate.get_delegate_list(address)
         if delegate_list == 'Retreiving delegation related mapping failed:RelatedList info is not found':
-            return None
+            return []
         else:
             return [DelegateInfo(delegate_info) for delegate_info in delegate_list]
 
@@ -120,3 +144,5 @@ class DelegateInfo(AttributeDict):
     RestrictingPlan: int
     RestrictingPlanHes: int
     CumulativeIncome: int
+    LockReleasedHes: int
+    LockRestrictingPlanHes: int
