@@ -1,8 +1,10 @@
 import time
 
+from loguru import logger
 from platon.main import get_default_modules
 from platon.middleware import gplaton_poa_middleware
-
+from platon_account import Account, DEFAULT_HRP
+from platon_utils import to_bech32_address, to_checksum_address, combomethod
 from platon_aide.calculator import Calculator
 from platon_aide.contract import Contract
 from platon_aide.delegate import Delegate
@@ -33,6 +35,7 @@ def get_modules(exclude: list = None):
 class Aide:
     """ 主类，platon各个子模块的集合体，同时支持创建账户、解码等非交易类的操作
     """
+    hrp: str = ''
 
     def __init__(self,
                  uri: str,
@@ -40,12 +43,12 @@ class Aide:
                  chain_id: int = None,
                  hrp: str = None,
                  economic: Economic = None,
-                 closed_api: list = None,
+                 exclude_api: list = None,
                  ):
         self.uri = uri
         self.gql_uri = gql_uri
         # web3相关设置
-        modules = get_modules(closed_api)
+        modules = get_modules(exclude_api)
         self.web3 = get_web3(uri, chain_id, hrp, modules=modules)
         self.web3.middleware_onion.inject(gplaton_poa_middleware, layer=0)
         self.hrp = hrp or self.web3.hrp
@@ -87,28 +90,57 @@ class Aide:
         self.govern.set_result_type(result_type)
         self.contract.set_result_type(result_type)
 
-    def create_account(self):
+    @combomethod
+    def create_account(self, hrp=None):
         """ 创建账户
         """
-        account = self.platon.account.create(hrp=self.hrp)
-        address = account.address
-        private_key = account.privateKey.hex()[2:]
-        return address, private_key
+        hrp = hrp or self.hrp or DEFAULT_HRP
+        return Account.create(hrp=hrp)
 
-    def create_hd_account(self):
+    @combomethod
+    def create_hd_account(self, hrp=None):
         """ 创建HD账户
         """
-        # todo: coding
         pass
 
-    def wait_block(self, to_block=None, interval=3):
+    @combomethod
+    def create_keystore(self, passphrase, key=None):
+        """ 创建钱包文件
+        """
+        pass
+
+    @combomethod
+    def to_bech32_address(self, address, hrp=None):
+        """ 任意地址转换为platon形式的bech32地址
+        注意：非标准bech32地址
+        """
+        hrp = hrp or self.hrp or DEFAULT_HRP
+        return to_bech32_address(address, hrp=hrp)
+
+    @combomethod
+    def to_checksum_address(self, address):
+        """ 任意地址转换为checksum地址
+        """
+        return to_checksum_address(address)
+
+    def wait_block(self, to_block, time_out=None):
         """ 等待块高
         """
         current_block = self.platon.block_number
-        while current_block < to_block:
-            time.sleep(interval)
+        time_out = time_out or (to_block - current_block) * 3
+
+        for i in range(time_out):
+            time.sleep(1)
             current_block = self.platon.block_number
 
+            if i % 10 == 0:
+                logger.info(f'waiting block: {current_block} -> {to_block}')
+
+            if current_block >= to_block:
+                return
+
+        raise TimeoutError('wait block timeout!')
+
     def ec_recover(self, block_identifier):
         """ 获取出块节点公钥
         """
